@@ -27,6 +27,8 @@
 #include "file-data.h"
 #include "fr-process.h"
 
+#define PACKAGES(x) (x)
+
 #define FR_TYPE_COMMAND            (fr_command_get_type ())
 #define FR_COMMAND(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), FR_TYPE_COMMAND, FrCommand))
 #define FR_COMMAND_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), FR_TYPE_COMMAND, FrCommandClass))
@@ -74,15 +76,17 @@ struct _FrCommand
 	char          *filename;        /* archive file path. */
 	char          *e_filename;      /* escaped archive filename. */
 	const char    *mime_type;
+	gboolean       multi_volume;
 
 	/*<protected>*/
 
 	/* options */
 
 	char          *password;
-	gboolean       encrypt_header;
+	gboolean       encrypt_header : 1;
 	FrCompression  compression;
 	guint          volume_size;
+	gboolean       creating_archive;
 
 	/* features. */
 
@@ -142,9 +146,12 @@ struct _FrCommandClass
 				           FrProcError   *error);
 	const char ** (*get_mime_types)   (FrCommand     *comm);
 	FrCommandCap  (*get_capabilities) (FrCommand     *comm,
-					   const char    *mime_type);
+					   const char    *mime_type,
+					   gboolean       check_command);
 	void          (*set_mime_type)    (FrCommand     *comm,
 				           const char    *mime_type);
+	const char *  (*get_packages)     (FrCommand     *comm,
+					   const char    *mime_type);
 
 	/*<signals>*/
 
@@ -164,6 +171,8 @@ struct _FrCommandClass
 GType          fr_command_get_type            (void);
 void           fr_command_set_filename        (FrCommand     *comm,
 					       const char    *filename);
+void           fr_command_set_multi_volume    (FrCommand     *comm,
+					       const char    *filename);
 void           fr_command_list                (FrCommand     *comm);
 void           fr_command_add                 (FrCommand     *comm,
 					       const char    *from_file,
@@ -189,11 +198,14 @@ gboolean       fr_command_is_capable_of       (FrCommand     *comm,
 const char **  fr_command_get_mime_types      (FrCommand     *comm);
 void           fr_command_update_capabilities (FrCommand     *comm);
 FrCommandCap   fr_command_get_capabilities    (FrCommand     *comm,
-					       const char    *mime_type);
+					       const char    *mime_type,
+					       gboolean       check_command);
 void           fr_command_set_mime_type       (FrCommand     *comm,
 					       const char    *mime_type);
 gboolean       fr_command_is_capable_of       (FrCommand     *comm,
 					       FrCommandCaps  capabilities);
+const char *   fr_command_get_packages        (FrCommand     *comm,
+					       const char    *mime_type);
 
 /* protected functions */
 
